; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
; 
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
; 

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.

command.buffer.time = 1
;-| AI |-------------------------------------------------------------------
[command]
name = "AI"
command = F,U,B,D,x+b+c+z
time = 0
[command]
name = "AI"
command = B,U,B,D,x+b+c+z
time = 0
[command]
name = "AI"
command = F,s,B,D,x+b+c+z
time = 0
[command]
name = "AI"
command = F,U,B,D,x+b+c+a
time = 0
[command]
name = "AI"
command = F,U,c,D,x+b+c+z
time = 0
[command]
name = "AI"
command = U,U,B,D,x+b+c+z
time = 0

[command]
name = "AI"
command = x,x,x,x,x,x
time = 0
[command]
name = "AI"
command = y,y,y,y,y,y
time = 0
[command]
name = "AI"
command = z,z,z,z,z,z
time = 0
[command]
name = "AI"
command = a,a,a,a,a,a
time = 0
[command]
name = "AI"
command = b,b,b,b,b,b
time = 0
[command]
name = "AI"
command = c,c,c,c,c,c
time = 0
[command]
name = "AI"
command = s,s,s,s,s,s
time = 0

[command]
name = "AI"
command = B,DB,D,DF,F,UF,U,UB,B,DB,D,DF,F,UF,U,x+z+a+c+s
time = 0
[command]
name = "AI"
command = U,D,UF,DB,UB,D,DF,B,UF,D,UB,y+c+x+a
time = 0
[command]
name = "AI"
command = F,U,B,D,x+b+c+z
time = 0
[command]
name = "AI"
command = B,U,B,D,x+b+c+z
time = 0
[command]
name = "AI"
command = F,s,B,D,x+b+c+z
time = 0
[command]
name = "AI"
command = F,U,B,D,x+b+c+a
time = 0
[command]
name = "AI"
command = F,U,c,D,x+b+c+z
time = 0
[command]
name = "AI"
command = U,U,B,D,x+b+c+z
time = 0

[command]
name = "AI"
command = x,x,x,x,x,x
time = 0
[command]
name = "AI"
command = y,y,y,y,y,y
time = 0
[command]
name = "AI"
command = z,z,z,z,z,z
time = 0
[command]
name = "AI"
command = a,a,a,a,a,a
time = 0
[command]
name = "AI"
command = b,b,b,b,b,b
time = 0
[command]
name = "AI"
command = c,c,c,c,c,c
time = 0
[command]
name = "AI"
command = s,s,s,s,s,s
time = 0

[command]
name = "AI"
command = B,DB,D,DF,F,UF,U,UB,B,DB,D,DF,F,UF,U,x+z+a+c+s
time = 0
[command]
name = "AI"
command = U,D,UF,DB,UB,D,DF,B,UF,D,UB,y+c+x+a
time = 0
[command]
name = "AI"
command = z,z,z,z,z,z
time = 0
[command]
name = "AI"
command = a,a,a,a,a,a
time = 0
[command]
name = "AI"
command = b,b,b,b,b,b
time = 0
[command]
name = "AI"
command = c,c,c,c,c,c
time = 0
[command]
name = "AI"
command = s,s,s,s,s,s
time = 0

[command]
name = "AI"
command = B,DB,D,DF,F,UF,U,UB,B,DB,D,DF,F,UF,U,x+z+a+c+s
time = 0
[command]
name = "AI"
command = U,D,UF,DB,UB,D,DF,B,UF,D,UB,y+c+x+a
time = 0

;-| Super Motions |--------------------------------------------------------
[command]
name = "kamui"
command = D,DF,F,D,DF,F,x
time = 35

[command]
name = "kamui"
command = D,F,D,F,x
time = 35

[command]
name = "kamui"
command = D,DF,F,D,DF,F,y
time = 35

[command]
name = "kamui"
command = D,F,D,F,y
time = 35

[command]
name = "orochinagi"
command = D,DB,B,D,DF,F,x
time = 35

[command]
name = "orochinagi"
command = D,B,D,F,x
time = 35

[command]
name = "orochinagi"
command = D,DB,B,D,DF,F,y
time = 35

[command]
name = "orochinagi"
command = D,B,D,F,y
time = 35

[command]
name = "kamokura"
command = D,DF,F,D,DF,F,x+y
time = 35
[command]
name = "kamokura"
command = D,F,D,F,x+y
time = 35

[command]
name = "totsuka"
command = D,DB,B,D,DB,B,x+y
time = 35
[command]
name = "totsuka"
command = D,B,D,B,x+y
time = 35


[command]
name = "amanomurakumo"
command = D,DB,B,D,DB,B,x
time = 35

[command]
name = "amanomurakumo"
command = D,B,D,B,x
time = 35

[command]
name = "amanomurakumo"
command = D,DB,B,D,DB,B,y
time = 35

[command]
name = "amanomurakumo"
command = D,B,D,B,y
time = 35

[command]
name = "mushiki"
command = D,DB,B,D,DF,F,x+y
time = 35

[command]
name = "mushiki"
command = D,B,D,F,x+y
time = 35

;-| Special Motions |------------------------------------------------------
[command]
name = "aragami"
command = D,DF,F,x
time = 15

[command]
name = "aragami"
command = D,F,x
time = 15

[command]
name = "dokugami"
command = D,DF,F,y
time = 15

[command]
name = "dokugami"
command = D,F,y
time = 15

[command]
name = "yanosabi"
command = F,DF,D,DB,B,x
time = 15

[command]
name = "yanosabi"
command = F,D,B,x
time = 15

[command]
name = "yanosabi"
command = F,DF,D,DB,B,y
time = 25

[command]
name = "yanosabi"
command = F,D,B,y
time = 25

[command]
name = "gouhu"
command = F,D,DF,x
time = 15

[command]
name = "gouhu"
command = F,D,x
time = 15

[command]
name = "gouhu"
command = F,D,DF,y
time = 15

[command]
name = "gouhu"
command = F,D,y
time = 15

[command]
name = "kototsuki"
command = F,DF,D,DB,B,x
time = 25

[command]
name = "kototsuki"
command = F,D,B,x
time = 25

[command]
name = "75shiki"
command = D,DF,F,a
time = 15

[command]
name = "75shiki"
command = D,F,a
time = 15

[command]
name = "75shiki"
command = D,DF,F,b
time = 15

[command]
name = "75shiki"
command = D,F,b
time = 15


[command]
name = "yamibarai"
command = D,DF,F,z
time = 15

[command]
name = "yamibarai"
command = D,F,z
time = 15

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = y+b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "z"
command = x+a
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Single Dir |------------------------------------------------------------
[Command]
name = "fwd" ;Required (do not remove)
command = $F
time = 1

[Command]
name = "downfwd"
command = $DF
time = 1

[Command]
name = "down" ;Required (do not remove)
command = $D
time = 1

[Command]
name = "downback"
command = $DB
time = 1

[Command]
name = "back" ;Required (do not remove)
command = $B
time = 1

[Command]
name = "upback"
command = $UB
time = 1

[Command]
name = "up" ;Required (do not remove)
command = $U
time = 1

[Command]
name = "upfwd"
command = $UF
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd" ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holddownfwd"
command = /$DF
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownback"
command = /$DB
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdupback"
command = /$UB
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holdupfwd"
command = /$UF
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
[State -1]
type = ChangeState
value = 3030
triggerall = power>=2000
triggerall = command = "totsuka"
triggerall = (statetype != a)
trigger1 = ctrl

[State -1]
type = ChangeState
value = 3020
triggerall = power>=2000
triggerall = command = "kamokura"
triggerall = (statetype != a)
trigger1 = ctrl
trigger2 = stateno = 1090
trigger2 = time>=13

[State -1]
type = ChangeState
value = 3060
triggerall = power>=2000
triggerall = command = "mushiki"
triggerall = (statetype != a)
trigger1 = ctrl
trigger2 = stateno=[1000,1030]
trigger2 = time>=4
trigger3 = stateno=3001
trigger3 = time>=7
trigger4 = stateno=3021
trigger4 = time>=136
trigger5 = stateno = 1090
trigger5 = time>=13
trigger6 = stateno = 3012
trigger6 = time>=16

[State -1]
type = ChangeState
value = 3040
triggerall = power>=1000
triggerall = command = "amanomurakumo"
triggerall = (statetype != a)
trigger1 = ctrl
trigger2 = stateno=[1000,1030]
trigger2 = time>=4
trigger3 = stateno=3001
trigger3 = time>=7
trigger4 = stateno=3021
trigger4 = time>=136
trigger5 = stateno = 1090
trigger5 = time>=13

[State -1]
type = ChangeState
value = ifelse(statetype=a,3050,3010)
triggerall = power>=1000
triggerall = command = "orochinagi"
trigger1 = ctrl
trigger2 = stateno=[1000,1030]
trigger2 = time>=4
trigger3 = stateno=3001
trigger3 = time>=7
trigger4 = stateno=3021
trigger4 = time>=136
trigger5 = stateno=1070
trigger5 = time>=5
trigger6 = stateno = 1090
trigger6 = time>=13

[State -1]
type = ChangeState
value = 3000
triggerall = power>=1000
triggerall = command = "kamui"
triggerall = (statetype != a)
trigger1 = ctrl
trigger2 = stateno=[1000,1030]
trigger2 = time>=4
trigger3 = stateno=3021
trigger3 = time>=136
trigger4 = stateno = 1090
trigger4 = time>=13

[State -1]
type = ChangeState
value = 1070
triggerall = command = "75shiki"
triggerall = (statetype = a)
trigger1 = ctrl
trigger2 = stateno=[600,640]
trigger2 = time>=4
trigger3 = stateno = 1090
trigger3 = time>=13

[State -1]
type = ChangeState
value = 1080
triggerall = command = "75shiki"
triggerall = (statetype != a)
trigger1 = ctrl
trigger2 = stateno = 1090
trigger2 = time>=13

[State -1]
type = ChangeState
value = 1050
triggerall = command = "dokugami"
triggerall = (statetype != a)
trigger1 = ctrl

[State -1]
type = ChangeState
value = 1040
triggerall = command = "kototsuki"||command="yanosabi"
triggerall = (statetype != a)
trigger1 = ctrl
trigger2 = stateno = 1090
trigger2 = time>=13

[State -1]
type = ChangeState
value = 1090
triggerall = command = "yamibarai"
triggerall = (statetype != a)
trigger1 = ctrl

;===========================================================================
[State -1]
type = ChangeState
value = 1030
triggerall = command = "gouhu"
triggerall = (statetype != a)
trigger1 = ctrl
trigger2 = stateno = 450
trigger2 = time>=4
trigger3 = stateno = 200
trigger3 = time>=4
trigger4 = stateno = 210
trigger4 = time>=4
trigger5 = stateno = 230
trigger5 = time>=4
trigger6 = stateno = 400
trigger6 = time>=4
trigger7 = stateno = 410
trigger7 = time>=4
trigger8 = stateno = 430
trigger8 = time>=4
trigger9 = stateno = 440
trigger9 = time>=4
trigger10 = stateno = [240,241]
trigger10 = time>=4
trigger11 = stateno = [1010,1020]
trigger11 = time>=4
trigger12 = stateno = 1051
trigger12 = time>=4
trigger13 = stateno = 1090
trigger13 = time>=13

[State -1]
type = ChangeState
value = 1000
triggerall = command = "aragami"
triggerall = (statetype != a)
trigger1 = ctrl
trigger2 = stateno = 450
trigger2 = time>=4
trigger3 = stateno = 200
trigger3 = time>=4
trigger4 = stateno = 210
trigger4 = time>=4
trigger5 = stateno = 230
trigger5 = time>=4
trigger6 = stateno = 400
trigger6 = time>=4
trigger7 = stateno = 410
trigger7 = time>=4
trigger8 = stateno = 430
trigger8 = time>=4
trigger9 = stateno = 440
trigger9 = time>=4
trigger10 = stateno = [240,241]
trigger10 = time>=4
trigger11 = stateno = 1051
trigger11 = time>=4
trigger12 = stateno = 1090
trigger12 = time>=13
;---------------------------------------------------------------------------
; Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 620
triggerall = command = "y"
triggerall = command = "holddown"
triggerall = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = time>=4
trigger3 = stateno = 630
trigger3 = time>=4
trigger4 = stateno = 640
trigger4 = time>=4
trigger5 = stateno = 610
trigger5 = time>=4
;---------------------------------------------------------------------------
; Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = 450
triggerall = command = "b"
triggerall = command = "holddownfwd"
triggerall = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time>=4
trigger3 = stateno = 430
trigger3 = time>=4
trigger4 = stateno = 440
trigger4 = time>=4
trigger5 = stateno = 410
trigger5 = time>=4
;---------------------------------------------------------------------------
; Stand Strong Punch
[State -1, Stand Strong Punch]
type = ChangeState
value = ifelse(command="holdback",751,750)
triggerall = command = "z"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl||stateno=150&&power>=1000
;---------------------------------------------------------------------------
; Standing Strong Kick
[State -1, Standing Strong Kick]
type = ChangeState
value = ifelse(statetype!=a,700,710)
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = ctrl||stateno=150&&power>=1000
;===========================================================================
;---------------------------------------------------------------------------
; Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 1060
trigger2 = time>=25

;---------------------------------------------------------------------------
; Run Back
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 1060
trigger2 = time>=25
;---------------------------------------------------------------------------
; Throw
[State -1, Throw]
type = ChangeState
value = 830
triggerall = command = "b" || command = "c"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 10
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 10
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H
;---------------------------------------------------------------------------
; Throw
[State -1, Throw]
type = ChangeState
value = 800
triggerall = command = "y" || command = "z"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 10
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 10
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
; Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "s"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = anim = 230
trigger2 = stateno = 230
trigger2 = time>7
trigger3 = stateno = 200
trigger3 = time>=9
trigger4 = anim = 231
trigger4 = stateno = 230
trigger4 = time>3

;---------------------------------------------------------------------------
; Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = anim = 230
trigger2 = stateno = 230
trigger2 = time>7
trigger3 = stateno = 200
trigger3 = time>=9
trigger4 = anim = 231
trigger4 = stateno = 230
trigger4 = time>3

;---------------------------------------------------------------------------
; Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = anim = 230
trigger2 = stateno = 230
trigger2 = time>7
trigger3 = stateno = 200
trigger3 = time>=9
trigger4 = anim = 231
trigger4 = stateno = 230
trigger4 = time>3

;---------------------------------------------------------------------------
; Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = ifelse(p2bodydist x<=15,241,240)
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = anim = 230
trigger2 = stateno = 230
trigger2 = time>7
trigger3 = stateno = 200
trigger3 = time>=9
trigger4 = anim = 231
trigger4 = stateno = 230
trigger4 = time>3

;---------------------------------------------------------------------------
; Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time>=4
trigger3 = stateno = 430
trigger3 = time>=4

;---------------------------------------------------------------------------
; Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time>=4
trigger3 = stateno = 430
trigger3 = time>=4

;---------------------------------------------------------------------------
; Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time>=4
trigger3 = stateno = 430
trigger3 = time>=4

;---------------------------------------------------------------------------
; Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time>=4
trigger3 = stateno = 430
trigger3 = time>=4
;---------------------------------------------------------------------------
; Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 630
trigger2 = time>8

;---------------------------------------------------------------------------
; Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = time>8
trigger3 = stateno = 630
trigger3 = time>8
;---------------------------------------------------------------------------
; Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = time>8

;---------------------------------------------------------------------------
; Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = time>8
trigger3 = stateno = 630
trigger3 = time>8

;---------------------------------------------------------------------------
